/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * prctile.h
 *
 * Code generation for function 'prctile'
 *
 */

#ifndef PRCTILE_H
#define PRCTILE_H

/* Include files */
#include <cmath>
#include <math.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include "rt_nonfinite.h"
#include "rtwtypes.h"
//#include "omp.h"
#include "MAVEfast_types.h"

/* Function Declarations */
extern void prctile(const emxArray_real_T *x, const emxArray_real_T *p,
                    emxArray_real_T *y);

#endif

/* End of code generation (prctile.h) */
